re_date_list = [
    "\d{1,2}[\-/]\d{2,4}",
    "\d{1,2}\sgiờ",
    "năm\s\d{2,4}",
    "\d{1,2}h\d{1,2}[p]*",
    "\d{1,2}h\d{1,2}[p]*-\d{1,2}h\d{1,2}[p]*",
    "(ngày|tháng|tới|đến) \d{1,2}[\-/]\d{1,4}",
    "\d{4}[\-/]\d{2}[\-/]\d{2}",  # 2017-05-08T17:57:00
    "\d{4}[\-/]\d{2}[\-/]\d{2}t\d{2}:\d{2}:\d{2}",  # 2017-05-08T17:57:00
    "\d{1,2}[\-/\.]\d{1,2}[\-/\.]\d{1,4}",
    # "\d{1,2}-\d{1,2}/\d{1,2}",
]
